@@ -39,6 +39,7 @@ def test_meta_dispatch():
         '%%_PATCH_%_CHANGELOG_%_DATE_%_LABEL_%%': meta.weave_meta_part_change_log_date_label,
         '%%_PATCH_%_CHANGELOG_%_AUTHOR_%_LABEL_%%': meta.weave_meta_part_change_log_author_label,
         '%%_PATCH_%_CHANGELOG_%_DESCRIPTION_%_LABEL_%%': meta.weave_meta_part_change_log_description_label,
+        '%%_PATCH_%_APPROVALS_%_ADJUSTABLE_%_VERTICAL_%_SPACE_%%': meta.weave_meta_part_approvals_adjustable_vertical_space,
         '%%_PATCH_%_APPROVALS_%_ROLE_%_LABEL_%%': meta.weave_meta_part_approvals_role_label,
         '%%_PATCH_%_APPROVALS_%_NAME_%_LABEL_%%': meta.weave_meta_part_approvals_name_label,
         '%%_PATCH_%_APPROVALS_%_DATE_%_AND_%_SIGNATURE_%_LABEL_%%': meta.weave_meta_part_approvals_date_and_signature_label,
@@ -61,6 +62,7 @@ def test_meta_dispatch():
         '%%_PATCH_%_CHANGELOG_%_DATE_%_LABEL_%%': 'Date',
         '%%_PATCH_%_CHANGELOG_%_AUTHOR_%_LABEL_%%': 'Author',
         '%%_PATCH_%_CHANGELOG_%_DESCRIPTION_%_LABEL_%%': 'Description',
+        '%%_PATCH_%_APPROVALS_%_ADJUSTABLE_%_VERTICAL_%_SPACE_%%': '2.5em',
         '%%_PATCH_%_APPROVALS_%_ROLE_%_LABEL_%%': 'Approvals',
         '%%_PATCH_%_APPROVALS_%_NAME_%_LABEL_%%': 'Name',
         '%%_PATCH_%_APPROVALS_%_DATE_%_AND_%_SIGNATURE_%_LABEL_%%': 'Date and Signature',
@@ -93,6 +95,7 @@ def test_meta_dispatch_explicit():
         '%%_PATCH_%_CHANGELOG_%_DATE_%_LABEL_%%': meta.weave_meta_part_change_log_date_label,
         '%%_PATCH_%_CHANGELOG_%_AUTHOR_%_LABEL_%%': meta.weave_meta_part_change_log_author_label,
         '%%_PATCH_%_CHANGELOG_%_DESCRIPTION_%_LABEL_%%': meta.weave_meta_part_change_log_description_label,
+        '%%_PATCH_%_APPROVALS_%_ADJUSTABLE_%_VERTICAL_%_SPACE_%%': meta.weave_meta_part_approvals_adjustable_vertical_space,
         '%%_PATCH_%_APPROVALS_%_ROLE_%_LABEL_%%': meta.weave_meta_part_approvals_role_label,
         '%%_PATCH_%_APPROVALS_%_NAME_%_LABEL_%%': meta.weave_meta_part_approvals_name_label,
         '%%_PATCH_%_APPROVALS_%_DATE_%_AND_%_SIGNATURE_%_LABEL_%%': meta.weave_meta_part_approvals_date_and_signature_label,
@@ -115,6 +118,7 @@ def test_meta_dispatch_explicit():
         'change_log_date_label': 'Date',
         'change_log_author_label': 'Author',
         'change_log_description_label': 'Description',
+        'approvals_adjustable_vertical_space': '2.5em',
         'approvals_role_label': 'Approvals',
         'approvals_name_label': 'Name',
         'approvals_date_and_signature_label': 'Date and Signature',
@@ -137,6 +141,7 @@ def test_meta_dispatch_explicit():
         '%%_PATCH_%_CHANGELOG_%_DATE_%_LABEL_%%': mapper['change_log_date_label'],
         '%%_PATCH_%_CHANGELOG_%_AUTHOR_%_LABEL_%%': mapper['change_log_author_label'],
         '%%_PATCH_%_CHANGELOG_%_DESCRIPTION_%_LABEL_%%': mapper['change_log_description_label'],
+        '%%_PATCH_%_APPROVALS_%_ADJUSTABLE_%_VERTICAL_%_SPACE_%%': mapper['approvals_adjustable_vertical_space'],
         '%%_PATCH_%_APPROVALS_%_ROLE_%_LABEL_%%': mapper['approvals_role_label'],
         '%%_PATCH_%_APPROVALS_%_NAME_%_LABEL_%%': mapper['approvals_name_label'],
         '%%_PATCH_%_APPROVALS_%_DATE_%_AND_%_SIGNATURE_%_LABEL_%%': mapper['approvals_date_and_signature_label'],
